@@ -238,7 +238,8 @@ void ChartAxisElement::handleTitleVisibleChanged(bool visible)
 
 void ChartAxisElement::handleLabelsAngleChanged(int angle)
 {
-    foreach (QGraphicsItem *item, m_labels->childItems())
+    const auto items = m_labels->childItems();
+    for (QGraphicsItem *item : items)
         item->setRotation(angle);
 
     QGraphicsLayoutItem::updateGeometry();
@@ -247,13 +248,15 @@ void ChartAxisElement::handleLabelsAngleChanged(int angle)
 
 void ChartAxisElement::handleLabelsBrushChanged(const QBrush &brush)
 {
-    foreach (QGraphicsItem *item, m_labels->childItems())
+    const auto items = m_labels->childItems();
+    for (QGraphicsItem *item : items)
         static_cast<QGraphicsTextItem *>(item)->setDefaultTextColor(brush.color());
 }
 
 void ChartAxisElement::handleLabelsFontChanged(const QFont &font)
 {
-    foreach (QGraphicsItem *item, m_labels->childItems())
+    const auto items = m_labels->childItems();
+    for (QGraphicsItem *item : items)
         static_cast<QGraphicsTextItem *>(item)->setFont(font);
     QGraphicsLayoutItem::updateGeometry();
     presenter()->layout()->invalidate();
@@ -292,6 +295,8 @@ void ChartAxisElement::handleVisibleChanged(bool visible)
         m_shades->setVisible(visible);
         m_labels->setVisible(visible);
         m_title->setVisible(visible);
+        if (m_colorScale)
+            m_colorScale->setVisible(visible);
     } else {
         m_grid->setVisible(axis()->isGridLineVisible());
         m_arrow->setVisible(axis()->isLineVisible());
@@ -434,7 +439,7 @@ void ChartAxisElement::prepareColorScale(const qreal width, const qreal height)
             } else {
                 gradient = QLinearGradient(QPointF(0, 0), QPointF(0, height));
                 for (int i = colorAxis->gradient().stops().size() - 1; i >= 0; --i) {
-                    const auto &stop = colorAxis->gradient().stops()[i];
+                    auto stop = colorAxis->gradient().stops()[i];
                     gradient.setColorAt(1 - stop.first, stop.second);
                 }
             }
