@@ -1,6 +1,8 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
+#undef QT_NO_FOREACH // this file contains unported legacy Q_FOREACH uses
+
 #include <QtCharts/QBarCategoryAxis>
 #include <QtCharts/QCandlestickLegendMarker>
 #include <QtCharts/QCandlestickSeries>
@@ -33,7 +35,7 @@ QT_BEGIN_NAMESPACE
     drawn to the same category. When using QValueAxis or QDateTimeAxis, candlestick items sharing a
     timestamp will overlap each other.
 
-    See the \l {Candlestick Chart Example} {candlestick chart example} to learn how to create
+    See the \l {Charts with Widgets Gallery} to learn how to create
     a candlestick chart.
     \image examples_candlestickchart.png
 
@@ -43,7 +45,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmltype CandlestickSeries
     \since QtCharts 2.2
-    \instantiates QCandlestickSeries
+    \nativetype QCandlestickSeries
     \inqmlmodule QtCharts
     \inherits AbstractSeries
     \brief Represents a series of data as candlesticks.
