@@ -23,7 +23,7 @@ QT_BEGIN_NAMESPACE
 
  A theme is a built-in collection of UI style related settings applied to all
  the visual elements of a chart, such as colors, pens, brushes, and fonts of
- series, as well as axes, title, and legend. The \l {Chart themes example}
+ series, as well as axes, title, and legend. The \l {Charts with Widgets Gallery}
  illustrates how to use themes.
 
  \note Changing the theme will overwrite all customizations previously applied
@@ -274,7 +274,8 @@ void QChart::removeSeries(QAbstractSeries *series)
  */
 void QChart::removeAllSeries()
 {
-    foreach (QAbstractSeries *s ,  d_ptr->m_dataset->series()){
+    const auto series = d_ptr->m_dataset->series();
+    for (QAbstractSeries *s : series) {
         removeSeries(s);
         delete s;
     }
@@ -485,12 +486,14 @@ QList<QAbstractAxis *> QChart::axes(Qt::Orientations orientation, QAbstractSerie
     QList<QAbstractAxis *> result ;
 
     if (series) {
-        foreach (QAbstractAxis *axis, series->attachedAxes()){
+        const auto axes = series->attachedAxes();
+        for (QAbstractAxis *axis : axes) {
             if (orientation.testFlag(axis->orientation()))
                 result << axis;
         }
     } else {
-        foreach (QAbstractAxis *axis, d_ptr->m_dataset->axes()){
+        const auto axes = d_ptr->m_dataset->axes();
+        for (QAbstractAxis *axis : axes) {
             if (orientation.testFlag(axis->orientation()) && !result.contains(axis))
                 result << axis;
         }
@@ -737,9 +740,9 @@ QList<QAbstractSeries *> QChart::series() const
 */
 void QChart::setAxisX(QAbstractAxis *axis ,QAbstractSeries *series)
 {
-    QList<QAbstractAxis*> list = axes(Qt::Horizontal, series);
+    const QList<QAbstractAxis*> list = axes(Qt::Horizontal, series);
 
-    foreach (QAbstractAxis* a, list) {
+    for (QAbstractAxis *a : list) {
         d_ptr->m_dataset->removeAxis(a);
         delete a;
     }
@@ -762,9 +765,9 @@ void QChart::setAxisX(QAbstractAxis *axis ,QAbstractSeries *series)
 */
 void QChart::setAxisY(QAbstractAxis *axis ,QAbstractSeries *series)
 {
-    QList<QAbstractAxis*> list = axes(Qt::Vertical, series);
+    const QList<QAbstractAxis*> list = axes(Qt::Vertical, series);
 
-    foreach (QAbstractAxis* a, list) {
+    for (QAbstractAxis *a : list) {
         d_ptr->m_dataset->removeAxis(a);
         delete a;
     }
